# Time-resolved optical emission spectroscopy in CO2 nanosecond pulsed discharges

This folder contains experimental data underlying the publication by M. Ceppelli *et al*: Time-resolved optical emission spectroscopy in CO2 nanosecond pulsed discharges, published in PSST in 2021.

DOI: https://doi.org/10.1088/1361-6595/ac2411

Each subfolder contains an additional `README.md` file that described the data format and relevant units of the data contained within.



Authors: M. Ceppelli , T.P.W. Salden, L. M. Martini, G. Dilecce and P. Tosi

Corresponding authors: G. Dilecce (giorgio.dilecce@cnr.it), T.P.W.Salden (t.p.w.salden@tue.nl)



### Purpose of the data

The data deals with the investigation of a nanosecond repetitively pulsed discharge in CO2, using optical emission spectroscopy, to establish time-resolved gas temperature and electron density profiles.

The discharge is a pin-to-pin configuration, driven by a MegaImpulse NPG18/100K power supply and operating in either continuous mode (single pulse operation at either 200 Hz or 1.0 kHz) or burst mode (2-pulse sequences at 90 kHz, with 200 Hz repetition rate per sequence), using either 52%, 72% or 92% input energy to drive an atmospheric pressure discharge in pure CO2 with occasional admixture of nitrogen.



A Teledyne LeCroy HD9100 oscilloscope recorded signals from a Tektronix P6015A voltage probe and a Magnelab CT-D-1.0 I/V converter for I-V characteristics.

Spectrally unresolved emission was recorded with a Hamamatsu R2949 photomultiplier tube.

Time-resolved emission by the discharge was recorded with Andor iStar  DH334T-18U ICCD camera, coupled to a Andor Shamrock SR303i-b, equipped with three gratings (600 gr/mm, 1200 gr/mm, 2400 gr/mm). 

The spectral response has been calibrated with a Avantes Avalight-DH-BAL-CAL spectral lamp.

Electron densities are calculated based on the Stark broadening of the atomic oxygen triplet at 777 nm and cross-checked with the Stark broadening for atomic carbon at 247 nm.

Gas temperatures are established from the N2 second positive system emission, occurring when admixing 5% of N2 into the CO2 gas flow.



## Datasets

The data contained within this set is split into four subfolders; within each folder there is a accompanying README file with details on data format, units, etc.

An overview of the data in each folder is as follows:

* **IVscope**: contains oscilloscope traces of the I-V characteristics of the discharge, along with spectrally unresolved emission as recorded by a photomultiplier tube.

* **Spectra**: Recorded spectra using the spectral calibration

* **Stark**: Time-resolved spectra for the aforementioned O and C lines, along with corresponding fit parameters and calculated electron densities from the fitted Stark width.

* **Thermometry**: Spectra of the N2 second positive system, CN violet system and C2 Swan bands to illustrate the rotational temperatures for each of these systems. Alongside, contains time-resolved rotational temperatures for the N2 SPS, for both in-pulse as well as the afterglow of a single pulse discharge event.



# Acknowledgements

This project has received funding from the European Union’s Horizon 2020 research and innovation programme under the Marie Sklodowska-Curie grant agreement No. 813393. 

M. Ceppelli acknowledges support by the Progetto Strategico di Ateneo ERICSOL of the University of Trento.


